==> scalamock_2.11-4.1.0-sources.jar: org/scalamock/handlers/Handlers.scala <==
// Copyright (c) 2011-2015 ScalaMock Contributors (https://github.com/paulbutcher/ScalaMock/graphs/contributors)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

package org.scalamock.handlers

import scala.collection.mutable.ListBuffer

private[scalamock] abstract class Handlers extends Handler {
  
  def add(handler: Handler) {
    handlers += handler
  }
  
  def isSatisfied = handlers forall (_.isSatisfied)
  
  override def toString = 
    handlers.map { h => 
      h.toString.lines map { l => "  "+ l }
    }.flatten.mkString(s"$prefix {\n", "\n", "\n}")
  
  protected val handlers = new ListBuffer[Handler]
  
  protected val prefix: String
}

==> scalamock_2.12-4.3.0-sources.jar: org/scalamock/handlers/Handlers.scala <==
// Copyright (c) 2011-2015 ScalaMock Contributors (https://github.com/paulbutcher/ScalaMock/graphs/contributors)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

package org.scalamock.handlers

import scala.collection.mutable.ListBuffer

private[scalamock] abstract class Handlers extends Handler {
  
  def add(handler: Handler): Unit = {
    handlers += handler
  }
  
  def isSatisfied = handlers forall (_.isSatisfied)
  
  override def toString = 
    handlers.map { h =>
      h.toString.lines.toArray.map { l => "  " + l}
    }.flatten.mkString(s"$prefix {\n", "\n", "\n}")
  
  protected val handlers = new ListBuffer[Handler]
  
  protected val prefix: String
}
